@@ -15,11 +15,13 @@ if TYPE_CHECKING:
     from diff_diff.power import PowerResults, SimulationPowerResults
     from diff_diff.results import MultiPeriodDiDResults
     from diff_diff.staggered import CallawaySantAnnaResults
+    from diff_diff.sun_abraham import SunAbrahamResults
 
 # Type alias for results that can be plotted
 PlottableResults = Union[
     "MultiPeriodDiDResults",
     "CallawaySantAnnaResults",
+    "SunAbrahamResults",
     pd.DataFrame,
 ]
 
@@ -360,7 +362,8 @@ def _extract_plot_data(
 
     raise TypeError(
         f"Cannot extract plot data from {type(results).__name__}. "
-        "Expected MultiPeriodDiDResults, CallawaySantAnnaResults, or DataFrame."
+        "Expected MultiPeriodDiDResults, CallawaySantAnnaResults, "
+        "SunAbrahamResults, or DataFrame."
     )
 
 
